summaryrefslogtreecommitdiff
path: root/TAO
diff options
context:
space:
mode:
authorgokhale <asgokhale@users.noreply.github.com>1998-05-14 21:40:37 +0000
committergokhale <asgokhale@users.noreply.github.com>1998-05-14 21:40:37 +0000
commit83d0ae7cec21db0b184c24e427ccd9116627ee77 (patch)
tree2aafd5959d787a80d94b1535844ff175ec2e1629 /TAO
parent814d1fe0f8b866f53f8b2363925dbb72b0e365e0 (diff)
downloadATCD-83d0ae7cec21db0b184c24e427ccd9116627ee77.tar.gz
*** empty log message ***
Diffstat (limited to 'TAO')
-rw-r--r--TAO/ChangeLog-98c36
-rw-r--r--TAO/TAO_IDL/Makefile2
-rw-r--r--TAO/TAO_IDL/be/be_visitor_constant.cpp4
-rw-r--r--TAO/TAO_IDL/be/be_visitor_interface.cpp7
-rw-r--r--TAO/TAO_IDL/be/be_visitor_module.cpp5
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation.cpp7
-rw-r--r--TAO/tao/POAS.cpp684
-rw-r--r--TAO/tao/PolicyS.cpp68
-rw-r--r--TAO/tao/Server_Request.cpp59
-rw-r--r--TAO/tao/Server_Request.h10
-rw-r--r--TAO/tao/decode.cpp6
-rw-r--r--TAO/tao/orbconf.h13
12 files changed, 508 insertions, 393 deletions
diff --git a/TAO/ChangeLog-98c b/TAO/ChangeLog-98c
index 5a20aad84f3..98a33d76d68 100644
--- a/TAO/ChangeLog-98c
+++ b/TAO/ChangeLog-98c
@@ -1,3 +1,39 @@
+Thu May 14 16:39:15 1998 Aniruddha Gokhale <gokhale@mambo.cs.wustl.edu>
+
+ * tao/Server_Request.{h,cpp}: Added an extra environment parameter
+ to the marshal method. This change was required since we wanted to
+ keep the ORB related exceptions and the user supplied
+ operation-raised exceptions to be separate.
+
+ * tao/{POAS,PolicyS}.cpp: Made several changes to the IDL
+ compiler-generated code that were necessary due to the changes
+ made to the Server_Request's marshal interface explained above.
+
+ * tao/{encode,decode}.cpp: Made a minor change by passing the
+ address of the void pointer for the string and object cases. This
+ needs to be thoroughly tested.
+
+ * tao/orbconf.h: Added a conditional macro called TAO_NAMESPACE
+ that generates either "namespace" or "struct".
+
+ * TAO_IDL/be/be_visitor_module.cpp: The code for the module now
+ uses the TAO_NAMESPACE macro.
+
+ * TAO_IDL/be/be_visitor_constant.cpp: We were not checking of the
+ constant was imported or not. In addition, inside the stub
+ generation code, we were incorrectly checking if the header was
+ generated or not. Thanks to Andrew Harbick"
+ <aharbick@opentext.com> for providing the bug report that led to
+ this fix.
+
+ * TAO_IDL/be/be_visitor_operation.cpp: Modifications that were
+ necessary due to the changes in the Server_Request class and our
+ policy of distinguishing between ORB raised and user-raised
+ exceptions.
+
+ * TAO_IDL/be/be_visitor_interface.cpp: Similar changes as in
+ be_visitor_operation.cpp for the _is_a_skel skeletons.
+
Thu May 14 15:20:28 1998 David L. Levine <levine@cs.wustl.edu>
* tests/Quoter/Makefile: moved TAO_ROOT definition outside of
diff --git a/TAO/TAO_IDL/Makefile b/TAO/TAO_IDL/Makefile
index 12f40f29f50..bc000ab41c4 100644
--- a/TAO/TAO_IDL/Makefile
+++ b/TAO/TAO_IDL/Makefile
@@ -188,7 +188,7 @@ endif # ! CROSS-COMPILE
tags:
rm -f TAGS
- etags -C include/*.h be_include/*.h
+ etags -C tao_idl.cpp include/*.h be_include/*.h
etags -a ast/*.cpp util/*.cpp narrow/*.cpp \
driver/*.cpp fe/*.cpp be/*.cpp
diff --git a/TAO/TAO_IDL/be/be_visitor_constant.cpp b/TAO/TAO_IDL/be/be_visitor_constant.cpp
index f2b2d722164..4bb9d190ba4 100644
--- a/TAO/TAO_IDL/be/be_visitor_constant.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_constant.cpp
@@ -44,7 +44,7 @@ be_visitor_constant_ch::visit_constant (be_constant *node)
{
TAO_OutStream *os = this->ctx_->stream ();
- if (!node->cli_hdr_gen ())
+ if (!node->cli_hdr_gen () && !node->imported ())
{
// if we are defined in the outermost scope, then the value is assigned
// to us here itself, else it will be in the *.cpp file
@@ -84,7 +84,7 @@ be_visitor_constant_cs::visit_constant (be_constant *node)
{
TAO_OutStream *os = this->ctx_->stream ();
- if (!node->cli_hdr_gen ())
+ if (!node->cli_stub_gen () && !node->imported ())
{
if (node->is_nested ())
{
diff --git a/TAO/TAO_IDL/be/be_visitor_interface.cpp b/TAO/TAO_IDL/be/be_visitor_interface.cpp
index c87706de243..9d93f187661 100644
--- a/TAO/TAO_IDL/be/be_visitor_interface.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_interface.cpp
@@ -1357,7 +1357,9 @@ be_visitor_interface_ss::visit_interface (be_interface *node)
*os << "};" << be_nl;
*os << "static const TAO_Call_Data_Skel " << node->flatname ()
<< "_is_a_calldata = " << be_nl;
- *os << "{\"_is_a\", 1, 2, " << node->flatname () << "_is_a_paramdata};" << be_nl;
+ *os << "{\"_is_a\", 1, 2, " << node->flatname () << "_is_a_paramdata};"
+ << be_nl;
+ *os << "CORBA::Environment _tao_skel_environment;" << be_nl;
*os << node->full_skel_name () << "_ptr _tao_impl = ("
<< node->full_skel_name () << "_ptr) _tao_object_reference;"
<< be_nl;
@@ -1370,10 +1372,11 @@ be_visitor_interface_ss::visit_interface (be_interface *node)
<< "&_tao_value" << be_uidt_nl
<< ");" << be_nl;
*os << "if (_tao_environment.exception () != 0) return;" << be_nl;
- *os << "_tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);"
+ *os << "_tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);"
<< be_nl;
*os << "_tao_server_request.marshal (" << be_idt_nl
<< "_tao_environment, " << be_nl
+ << "_tao_skel_environment," << be_nl
<< "&" << node->flatname () << "_is_a_calldata, " << be_nl
<< "&_tao_retval, " << be_nl
<< "&_tao_value" << be_uidt_nl
diff --git a/TAO/TAO_IDL/be/be_visitor_module.cpp b/TAO/TAO_IDL/be/be_visitor_module.cpp
index 5b7107f9886..697e7ceaf8a 100644
--- a/TAO/TAO_IDL/be/be_visitor_module.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_module.cpp
@@ -577,10 +577,9 @@ be_visitor_module_ch::visit_module (be_module *node)
os->indent (); // start from whatever indentation level we were at
// now generate the class definition
- *os << "class " << idl_global->export_macro ()
+ *os << "TAO_NAMESPACE " << idl_global->export_macro ()
<< " " << node->local_name () << be_nl
- << "{" << be_nl
- << "public:\n";
+ << "{\n";
os->incr_indent (0);
// generate code for the module definition by traversing thru the
diff --git a/TAO/TAO_IDL/be/be_visitor_operation.cpp b/TAO/TAO_IDL/be/be_visitor_operation.cpp
index 74cf3242159..3ceb559ac9f 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation.cpp
@@ -853,8 +853,10 @@ be_visitor_operation_ss::visit_operation (be_operation *node)
}
*os << node->flatname () << "_paramdata};\n\n";
- // get the right object implementation.
os->indent ();
+ // declare an environment variable for user raised exceptions
+ *os << "CORBA::Environment _tao_skel_environment;" << be_nl;
+ // get the right object implementation.
*os << intf->full_skel_name () << " *_tao_impl = ("
<< intf->full_skel_name () << " *)_tao_object_reference;\n";
@@ -987,7 +989,7 @@ be_visitor_operation_ss::visit_operation (be_operation *node)
if (node->argument_count () > 0)
*os << ",\n";
os->indent ();
- *os << "_tao_environment";
+ *os << "_tao_skel_environment";
// end the upcall
*os << be_uidt_nl;
*os << ");\n";
@@ -1020,6 +1022,7 @@ be_visitor_operation_ss::visit_operation (be_operation *node)
os->indent ();
*os << "_tao_server_request.marshal (" << be_idt_nl
<< "_tao_environment, " << be_nl
+ << "_tao_skel_environment, " << be_nl
<< "&";
// check if we are an attribute node in disguise
if (this->ctx_->attribute ())
diff --git a/TAO/tao/POAS.cpp b/TAO/tao/POAS.cpp
index bf01ef1cc4f..9ca733f3c19 100644
--- a/TAO/tao/POAS.cpp
+++ b/TAO/tao/POAS.cpp
@@ -32,9 +32,10 @@ void POA_PortableServer::CurrentBase::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_CurrentBase_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -46,15 +47,16 @@ void POA_PortableServer::CurrentBase::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_CurrentBase_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_CurrentBase_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -64,12 +66,12 @@ void POA_PortableServer::CurrentBase::_is_a_skel (
CORBA::Boolean POA_PortableServer::CurrentBase::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/CurrentBase:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -122,12 +124,12 @@ POA_PortableServer::CurrentBase_ptr POA_PortableServer::_tao_collocated_CurrentB
CORBA::Boolean POA_PortableServer::_tao_collocated_CurrentBase::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -164,9 +166,10 @@ void POA_PortableServer::ThreadPolicy::_get_value_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel _get_PortableServer_ThreadPolicy_value_paramdata [] =
{
{PortableServer::_tc_ThreadPolicyValue, 0, 0}
@@ -178,16 +181,17 @@ void POA_PortableServer::ThreadPolicy::_get_value_skel (
POA_PortableServer::ThreadPolicy *_tao_impl = (POA_PortableServer::ThreadPolicy *)_tao_object_reference;
PortableServer::ThreadPolicyValue _tao_retval;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&_get_PortableServer_ThreadPolicy_value_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->value (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&_get_PortableServer_ThreadPolicy_value_calldata,
&_tao_retval
);
@@ -197,9 +201,10 @@ void POA_PortableServer::ThreadPolicy::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_ThreadPolicy_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -211,15 +216,16 @@ void POA_PortableServer::ThreadPolicy::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_ThreadPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_ThreadPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -229,13 +235,13 @@ void POA_PortableServer::ThreadPolicy::_is_a_skel (
CORBA::Boolean POA_PortableServer::ThreadPolicy::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/ThreadPolicy:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/Policy:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -291,47 +297,47 @@ POA_PortableServer::ThreadPolicy_ptr POA_PortableServer::_tao_collocated_ThreadP
CORBA::Boolean POA_PortableServer::_tao_collocated_ThreadPolicy::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Policy_ptr POA_PortableServer::_tao_collocated_ThreadPolicy::copy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->copy (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_ThreadPolicy::destroy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->destroy (
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::PolicyType POA_PortableServer::_tao_collocated_ThreadPolicy::policy_type (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->policy_type (_tao_environment);
+ return this->servant_->policy_type (_tao_orb_environment);
}
PortableServer::ThreadPolicyValue
POA_PortableServer::_tao_collocated_ThreadPolicy::value (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->value(_tao_environment);
+ return this->servant_->value(_tao_orb_environment);
}
PortableServer::ThreadPolicy*
@@ -366,9 +372,10 @@ void POA_PortableServer::LifespanPolicy::_get_value_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel _get_PortableServer_LifespanPolicy_value_paramdata [] =
{
{PortableServer::_tc_LifespanPolicyValue, 0, 0}
@@ -380,16 +387,17 @@ void POA_PortableServer::LifespanPolicy::_get_value_skel (
POA_PortableServer::LifespanPolicy *_tao_impl = (POA_PortableServer::LifespanPolicy *)_tao_object_reference;
PortableServer::LifespanPolicyValue _tao_retval;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&_get_PortableServer_LifespanPolicy_value_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->value (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&_get_PortableServer_LifespanPolicy_value_calldata,
&_tao_retval
);
@@ -399,9 +407,10 @@ void POA_PortableServer::LifespanPolicy::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_LifespanPolicy_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -413,15 +422,16 @@ void POA_PortableServer::LifespanPolicy::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_LifespanPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_LifespanPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -431,13 +441,13 @@ void POA_PortableServer::LifespanPolicy::_is_a_skel (
CORBA::Boolean POA_PortableServer::LifespanPolicy::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/LifespanPolicy:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/Policy:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -493,46 +503,46 @@ POA_PortableServer::LifespanPolicy_ptr POA_PortableServer::_tao_collocated_Lifes
CORBA::Boolean POA_PortableServer::_tao_collocated_LifespanPolicy::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Policy_ptr POA_PortableServer::_tao_collocated_LifespanPolicy::copy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->copy (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_LifespanPolicy::destroy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->destroy (
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::PolicyType POA_PortableServer::_tao_collocated_LifespanPolicy::policy_type (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->policy_type (_tao_environment);
+ return this->servant_->policy_type (_tao_orb_environment);
}
PortableServer::LifespanPolicyValue
POA_PortableServer::_tao_collocated_LifespanPolicy::value (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->value(_tao_environment);
+ return this->servant_->value(_tao_orb_environment);
}
PortableServer::LifespanPolicy*
@@ -567,9 +577,10 @@ void POA_PortableServer::IdUniquenessPolicy::_get_value_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel _get_PortableServer_IdUniquenessPolicy_value_paramdata [] =
{
{PortableServer::_tc_IdUniquenessPolicyValue, 0, 0}
@@ -581,16 +592,17 @@ void POA_PortableServer::IdUniquenessPolicy::_get_value_skel (
POA_PortableServer::IdUniquenessPolicy *_tao_impl = (POA_PortableServer::IdUniquenessPolicy *)_tao_object_reference;
PortableServer::IdUniquenessPolicyValue _tao_retval;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&_get_PortableServer_IdUniquenessPolicy_value_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->value (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&_get_PortableServer_IdUniquenessPolicy_value_calldata,
&_tao_retval
);
@@ -600,9 +612,10 @@ void POA_PortableServer::IdUniquenessPolicy::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_IdUniquenessPolicy_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -614,15 +627,16 @@ void POA_PortableServer::IdUniquenessPolicy::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_IdUniquenessPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_IdUniquenessPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -632,13 +646,13 @@ void POA_PortableServer::IdUniquenessPolicy::_is_a_skel (
CORBA::Boolean POA_PortableServer::IdUniquenessPolicy::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/IdUniquenessPolicy:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/Policy:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -694,46 +708,46 @@ POA_PortableServer::IdUniquenessPolicy_ptr POA_PortableServer::_tao_collocated_I
CORBA::Boolean POA_PortableServer::_tao_collocated_IdUniquenessPolicy::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Policy_ptr POA_PortableServer::_tao_collocated_IdUniquenessPolicy::copy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->copy (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_IdUniquenessPolicy::destroy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->destroy (
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::PolicyType POA_PortableServer::_tao_collocated_IdUniquenessPolicy::policy_type (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->policy_type (_tao_environment);
+ return this->servant_->policy_type (_tao_orb_environment);
}
PortableServer::IdUniquenessPolicyValue
POA_PortableServer::_tao_collocated_IdUniquenessPolicy::value (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->value(_tao_environment);
+ return this->servant_->value(_tao_orb_environment);
}
PortableServer::IdUniquenessPolicy*
@@ -768,9 +782,10 @@ void POA_PortableServer::IdAssignmentPolicy::_get_value_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel _get_PortableServer_IdAssignmentPolicy_value_paramdata [] =
{
{PortableServer::_tc_IdAssignmentPolicyValue, 0, 0}
@@ -782,16 +797,17 @@ void POA_PortableServer::IdAssignmentPolicy::_get_value_skel (
POA_PortableServer::IdAssignmentPolicy *_tao_impl = (POA_PortableServer::IdAssignmentPolicy *)_tao_object_reference;
PortableServer::IdAssignmentPolicyValue _tao_retval;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&_get_PortableServer_IdAssignmentPolicy_value_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->value (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&_get_PortableServer_IdAssignmentPolicy_value_calldata,
&_tao_retval
);
@@ -801,9 +817,10 @@ void POA_PortableServer::IdAssignmentPolicy::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_IdAssignmentPolicy_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -815,15 +832,16 @@ void POA_PortableServer::IdAssignmentPolicy::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_IdAssignmentPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_IdAssignmentPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -833,13 +851,13 @@ void POA_PortableServer::IdAssignmentPolicy::_is_a_skel (
CORBA::Boolean POA_PortableServer::IdAssignmentPolicy::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/IdAssignmentPolicy:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/Policy:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -895,46 +913,46 @@ POA_PortableServer::IdAssignmentPolicy_ptr POA_PortableServer::_tao_collocated_I
CORBA::Boolean POA_PortableServer::_tao_collocated_IdAssignmentPolicy::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Policy_ptr POA_PortableServer::_tao_collocated_IdAssignmentPolicy::copy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->copy (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_IdAssignmentPolicy::destroy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->destroy (
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::PolicyType POA_PortableServer::_tao_collocated_IdAssignmentPolicy::policy_type (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->policy_type (_tao_environment);
+ return this->servant_->policy_type (_tao_orb_environment);
}
PortableServer::IdAssignmentPolicyValue
POA_PortableServer::_tao_collocated_IdAssignmentPolicy::value (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->value(_tao_environment);
+ return this->servant_->value(_tao_orb_environment);
}
PortableServer::IdAssignmentPolicy*
@@ -969,9 +987,10 @@ void POA_PortableServer::ImplicitActivationPolicy::_get_value_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel _get_PortableServer_ImplicitActivationPolicy_value_paramdata [] =
{
{PortableServer::_tc_ImplicitActivationPolicyValue, 0, 0}
@@ -983,16 +1002,17 @@ void POA_PortableServer::ImplicitActivationPolicy::_get_value_skel (
POA_PortableServer::ImplicitActivationPolicy *_tao_impl = (POA_PortableServer::ImplicitActivationPolicy *)_tao_object_reference;
PortableServer::ImplicitActivationPolicyValue _tao_retval;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&_get_PortableServer_ImplicitActivationPolicy_value_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->value (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&_get_PortableServer_ImplicitActivationPolicy_value_calldata,
&_tao_retval
);
@@ -1002,9 +1022,10 @@ void POA_PortableServer::ImplicitActivationPolicy::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_ImplicitActivationPolicy_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -1016,15 +1037,16 @@ void POA_PortableServer::ImplicitActivationPolicy::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_ImplicitActivationPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_ImplicitActivationPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -1034,13 +1056,13 @@ void POA_PortableServer::ImplicitActivationPolicy::_is_a_skel (
CORBA::Boolean POA_PortableServer::ImplicitActivationPolicy::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/ImplicitActivationPolicy:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/Policy:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -1096,46 +1118,46 @@ POA_PortableServer::ImplicitActivationPolicy_ptr POA_PortableServer::_tao_colloc
CORBA::Boolean POA_PortableServer::_tao_collocated_ImplicitActivationPolicy::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Policy_ptr POA_PortableServer::_tao_collocated_ImplicitActivationPolicy::copy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->copy (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_ImplicitActivationPolicy::destroy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->destroy (
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::PolicyType POA_PortableServer::_tao_collocated_ImplicitActivationPolicy::policy_type (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->policy_type (_tao_environment);
+ return this->servant_->policy_type (_tao_orb_environment);
}
PortableServer::ImplicitActivationPolicyValue
POA_PortableServer::_tao_collocated_ImplicitActivationPolicy::value (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->value(_tao_environment);
+ return this->servant_->value(_tao_orb_environment);
}
PortableServer::ImplicitActivationPolicy*
@@ -1170,9 +1192,10 @@ void POA_PortableServer::ServantRetentionPolicy::_get_value_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel _get_PortableServer_ServantRetentionPolicy_value_paramdata [] =
{
{PortableServer::_tc_ServantRetentionPolicyValue, 0, 0}
@@ -1184,16 +1207,17 @@ void POA_PortableServer::ServantRetentionPolicy::_get_value_skel (
POA_PortableServer::ServantRetentionPolicy *_tao_impl = (POA_PortableServer::ServantRetentionPolicy *)_tao_object_reference;
PortableServer::ServantRetentionPolicyValue _tao_retval;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&_get_PortableServer_ServantRetentionPolicy_value_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->value (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&_get_PortableServer_ServantRetentionPolicy_value_calldata,
&_tao_retval
);
@@ -1203,9 +1227,10 @@ void POA_PortableServer::ServantRetentionPolicy::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_ServantRetentionPolicy_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -1217,15 +1242,16 @@ void POA_PortableServer::ServantRetentionPolicy::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_ServantRetentionPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_ServantRetentionPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -1235,13 +1261,13 @@ void POA_PortableServer::ServantRetentionPolicy::_is_a_skel (
CORBA::Boolean POA_PortableServer::ServantRetentionPolicy::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/ServantRetentionPolicy:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/Policy:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -1297,46 +1323,46 @@ POA_PortableServer::ServantRetentionPolicy_ptr POA_PortableServer::_tao_collocat
CORBA::Boolean POA_PortableServer::_tao_collocated_ServantRetentionPolicy::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Policy_ptr POA_PortableServer::_tao_collocated_ServantRetentionPolicy::copy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->copy (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_ServantRetentionPolicy::destroy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->destroy (
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::PolicyType POA_PortableServer::_tao_collocated_ServantRetentionPolicy::policy_type (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->policy_type (_tao_environment);
+ return this->servant_->policy_type (_tao_orb_environment);
}
PortableServer::ServantRetentionPolicyValue
POA_PortableServer::_tao_collocated_ServantRetentionPolicy::value (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->value(_tao_environment);
+ return this->servant_->value(_tao_orb_environment);
}
PortableServer::ServantRetentionPolicy*
@@ -1371,9 +1397,10 @@ void POA_PortableServer::RequestProcessingPolicy::_get_value_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel _get_PortableServer_RequestProcessingPolicy_value_paramdata [] =
{
{PortableServer::_tc_RequestProcessingPolicyValue, 0, 0}
@@ -1385,16 +1412,17 @@ void POA_PortableServer::RequestProcessingPolicy::_get_value_skel (
POA_PortableServer::RequestProcessingPolicy *_tao_impl = (POA_PortableServer::RequestProcessingPolicy *)_tao_object_reference;
PortableServer::RequestProcessingPolicyValue _tao_retval;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&_get_PortableServer_RequestProcessingPolicy_value_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->value (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&_get_PortableServer_RequestProcessingPolicy_value_calldata,
&_tao_retval
);
@@ -1404,9 +1432,10 @@ void POA_PortableServer::RequestProcessingPolicy::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_RequestProcessingPolicy_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -1418,15 +1447,16 @@ void POA_PortableServer::RequestProcessingPolicy::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_RequestProcessingPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_RequestProcessingPolicy_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -1436,13 +1466,13 @@ void POA_PortableServer::RequestProcessingPolicy::_is_a_skel (
CORBA::Boolean POA_PortableServer::RequestProcessingPolicy::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/RequestProcessingPolicy:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/Policy:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -1498,46 +1528,46 @@ POA_PortableServer::RequestProcessingPolicy_ptr POA_PortableServer::_tao_colloca
CORBA::Boolean POA_PortableServer::_tao_collocated_RequestProcessingPolicy::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Policy_ptr POA_PortableServer::_tao_collocated_RequestProcessingPolicy::copy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->copy (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_RequestProcessingPolicy::destroy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->destroy (
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::PolicyType POA_PortableServer::_tao_collocated_RequestProcessingPolicy::policy_type (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->policy_type (_tao_environment);
+ return this->servant_->policy_type (_tao_orb_environment);
}
PortableServer::RequestProcessingPolicyValue
POA_PortableServer::_tao_collocated_RequestProcessingPolicy::value (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->value(_tao_environment);
+ return this->servant_->value(_tao_orb_environment);
}
PortableServer::RequestProcessingPolicy*
@@ -1568,9 +1598,10 @@ void POA_PortableServer::POAManager::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_POAManager_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -1582,15 +1613,16 @@ void POA_PortableServer::POAManager::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_POAManager_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_POAManager_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -1600,12 +1632,12 @@ void POA_PortableServer::POAManager::_is_a_skel (
CORBA::Boolean POA_PortableServer::POAManager::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/POAManager:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -1658,56 +1690,56 @@ POA_PortableServer::POAManager_ptr POA_PortableServer::_tao_collocated_POAManage
CORBA::Boolean POA_PortableServer::_tao_collocated_POAManager::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_POAManager::activate (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->activate (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_POAManager::hold_requests (
CORBA::Boolean wait_for_completion,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->hold_requests (
wait_for_completion,
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_POAManager::discard_requests (
CORBA::Boolean wait_for_completion,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->discard_requests (
wait_for_completion,
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_POAManager::deactivate (
CORBA::Boolean etherealize_objects,
CORBA::Boolean wait_for_completion,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->deactivate (
etherealize_objects,
wait_for_completion,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -1740,9 +1772,10 @@ void POA_PortableServer::AdapterActivator::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_AdapterActivator_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -1754,15 +1787,16 @@ void POA_PortableServer::AdapterActivator::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_AdapterActivator_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_AdapterActivator_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -1772,12 +1806,12 @@ void POA_PortableServer::AdapterActivator::_is_a_skel (
CORBA::Boolean POA_PortableServer::AdapterActivator::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/AdapterActivator:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -1830,25 +1864,25 @@ POA_PortableServer::AdapterActivator_ptr POA_PortableServer::_tao_collocated_Ada
CORBA::Boolean POA_PortableServer::_tao_collocated_AdapterActivator::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Boolean POA_PortableServer::_tao_collocated_AdapterActivator::unknown_adapter (
PortableServer::POA_ptr parent,
const char* name,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->unknown_adapter (
parent,
name,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -1881,9 +1915,10 @@ void POA_PortableServer::ServantManager::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_ServantManager_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -1895,15 +1930,16 @@ void POA_PortableServer::ServantManager::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_ServantManager_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_ServantManager_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -1913,12 +1949,12 @@ void POA_PortableServer::ServantManager::_is_a_skel (
CORBA::Boolean POA_PortableServer::ServantManager::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/ServantManager:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -1971,12 +2007,12 @@ POA_PortableServer::ServantManager_ptr POA_PortableServer::_tao_collocated_Serva
CORBA::Boolean POA_PortableServer::_tao_collocated_ServantManager::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -2009,9 +2045,10 @@ void POA_PortableServer::ServantActivator::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_ServantActivator_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -2023,15 +2060,16 @@ void POA_PortableServer::ServantActivator::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_ServantActivator_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_ServantActivator_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -2041,13 +2079,13 @@ void POA_PortableServer::ServantActivator::_is_a_skel (
CORBA::Boolean POA_PortableServer::ServantActivator::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/ServantActivator:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/ServantManager:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -2103,25 +2141,25 @@ POA_PortableServer::ServantActivator_ptr POA_PortableServer::_tao_collocated_Ser
CORBA::Boolean POA_PortableServer::_tao_collocated_ServantActivator::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::Servant POA_PortableServer::_tao_collocated_ServantActivator::incarnate (
const PortableServer::ObjectId & oid,
PortableServer::POA_ptr adapter,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->incarnate (
oid,
adapter,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -2131,7 +2169,7 @@ void POA_PortableServer::_tao_collocated_ServantActivator::etherealize (
PortableServer::Servant serv,
CORBA::Boolean cleanup_in_progress,
CORBA::Boolean remaining_activations,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->etherealize (
@@ -2140,7 +2178,7 @@ void POA_PortableServer::_tao_collocated_ServantActivator::etherealize (
serv,
cleanup_in_progress,
remaining_activations,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -2173,9 +2211,10 @@ void POA_PortableServer::ServantLocator::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_ServantLocator_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -2187,15 +2226,16 @@ void POA_PortableServer::ServantLocator::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_ServantLocator_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_ServantLocator_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -2205,13 +2245,13 @@ void POA_PortableServer::ServantLocator::_is_a_skel (
CORBA::Boolean POA_PortableServer::ServantLocator::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/ServantLocator:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/ServantManager:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -2267,12 +2307,12 @@ POA_PortableServer::ServantLocator_ptr POA_PortableServer::_tao_collocated_Serva
CORBA::Boolean POA_PortableServer::_tao_collocated_ServantLocator::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -2281,7 +2321,7 @@ PortableServer::Servant POA_PortableServer::_tao_collocated_ServantLocator::prei
PortableServer::POA_ptr adapter,
const char * operation,
PortableServer::ServantLocator::Cookie & the_cookie,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->preinvoke (
@@ -2289,7 +2329,7 @@ PortableServer::Servant POA_PortableServer::_tao_collocated_ServantLocator::prei
adapter,
operation,
the_cookie,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -2299,7 +2339,7 @@ void POA_PortableServer::_tao_collocated_ServantLocator::postinvoke (
const char * operation,
PortableServer::ServantLocator::Cookie the_cookie,
PortableServer::Servant the_servant,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->postinvoke (
@@ -2308,7 +2348,7 @@ void POA_PortableServer::_tao_collocated_ServantLocator::postinvoke (
operation,
the_cookie,
the_servant,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -2341,9 +2381,10 @@ void POA_PortableServer::POA::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_POA_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -2355,15 +2396,16 @@ void POA_PortableServer::POA::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_POA_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_POA_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -2373,12 +2415,12 @@ void POA_PortableServer::POA::_is_a_skel (
CORBA::Boolean POA_PortableServer::POA::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/POA:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -2431,12 +2473,12 @@ POA_PortableServer::POA_ptr POA_PortableServer::_tao_collocated_POA::_get_servan
CORBA::Boolean POA_PortableServer::_tao_collocated_POA::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -2444,322 +2486,322 @@ PortableServer::POA_ptr POA_PortableServer::_tao_collocated_POA::create_POA (
const char* adapter_name,
PortableServer::POAManager_ptr a_POAManager,
const CORBA::PolicyList & policies,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_POA (
adapter_name,
a_POAManager,
policies,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::POA_ptr POA_PortableServer::_tao_collocated_POA::find_POA (
const char* adapter_name,
CORBA::Boolean activate_it,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->find_POA (
adapter_name,
activate_it,
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_POA::destroy (
CORBA::Boolean etherealize_objects,
CORBA::Boolean wait_for_completion,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->destroy (
etherealize_objects,
wait_for_completion,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::ThreadPolicy_ptr POA_PortableServer::_tao_collocated_POA::create_thread_policy (
PortableServer::ThreadPolicyValue value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_thread_policy (
value,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::LifespanPolicy_ptr POA_PortableServer::_tao_collocated_POA::create_lifespan_policy (
PortableServer::LifespanPolicyValue value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_lifespan_policy (
value,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::IdUniquenessPolicy_ptr POA_PortableServer::_tao_collocated_POA::create_id_uniqueness_policy (
PortableServer::IdUniquenessPolicyValue value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_id_uniqueness_policy (
value,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::IdAssignmentPolicy_ptr POA_PortableServer::_tao_collocated_POA::create_id_assignment_policy (
PortableServer::IdAssignmentPolicyValue value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_id_assignment_policy (
value,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::ImplicitActivationPolicy_ptr POA_PortableServer::_tao_collocated_POA::create_implicit_activation_policy (
PortableServer::ImplicitActivationPolicyValue value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_implicit_activation_policy (
value,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::ServantRetentionPolicy_ptr POA_PortableServer::_tao_collocated_POA::create_servant_retention_policy (
PortableServer::ServantRetentionPolicyValue value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_servant_retention_policy (
value,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::RequestProcessingPolicy_ptr POA_PortableServer::_tao_collocated_POA::create_request_processing_policy (
PortableServer::RequestProcessingPolicyValue value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_request_processing_policy (
value,
- _tao_environment
+ _tao_orb_environment
);
}
char*
POA_PortableServer::_tao_collocated_POA::the_name (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->the_name(_tao_environment);
+ return this->servant_->the_name(_tao_orb_environment);
}
PortableServer::POA_ptr
POA_PortableServer::_tao_collocated_POA::the_parent (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->the_parent(_tao_environment);
+ return this->servant_->the_parent(_tao_orb_environment);
}
PortableServer::POAManager_ptr
POA_PortableServer::_tao_collocated_POA::the_POAManager (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->the_POAManager(_tao_environment);
+ return this->servant_->the_POAManager(_tao_orb_environment);
}
PortableServer::AdapterActivator_ptr
POA_PortableServer::_tao_collocated_POA::the_activator (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
- return this->servant_->the_activator(_tao_environment);
+ return this->servant_->the_activator(_tao_orb_environment);
}
void POA_PortableServer::_tao_collocated_POA::the_activator (
PortableServer::AdapterActivator_ptr _tao_value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->the_activator (
_tao_value,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::ServantManager_ptr POA_PortableServer::_tao_collocated_POA::get_servant_manager (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->get_servant_manager (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_POA::set_servant_manager (
PortableServer::ServantManager_ptr imgr,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->set_servant_manager (
imgr,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::Servant POA_PortableServer::_tao_collocated_POA::get_servant (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->get_servant (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_POA::set_servant (
PortableServer::Servant p_servant,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->set_servant (
p_servant,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::ObjectId * POA_PortableServer::_tao_collocated_POA::activate_object (
PortableServer::Servant p_servant,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->activate_object (
p_servant,
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_POA::activate_object_with_id (
const PortableServer::ObjectId & id,
PortableServer::Servant p_servant,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->activate_object_with_id (
id,
p_servant,
- _tao_environment
+ _tao_orb_environment
);
}
void POA_PortableServer::_tao_collocated_POA::deactivate_object (
const PortableServer::ObjectId & oid,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->deactivate_object (
oid,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Object_ptr POA_PortableServer::_tao_collocated_POA::create_reference (
const char *intf,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_reference (
intf,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Object_ptr POA_PortableServer::_tao_collocated_POA::create_reference_with_id (
const PortableServer::ObjectId & oid,
const char *intf,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->create_reference_with_id (
oid,
intf,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::ObjectId * POA_PortableServer::_tao_collocated_POA::servant_to_id (
PortableServer::Servant p_servant,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->servant_to_id (
p_servant,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Object_ptr POA_PortableServer::_tao_collocated_POA::servant_to_reference (
PortableServer::Servant p_servant,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->servant_to_reference (
p_servant,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::Servant POA_PortableServer::_tao_collocated_POA::reference_to_servant (
CORBA::Object_ptr reference,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->reference_to_servant (
reference,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::ObjectId * POA_PortableServer::_tao_collocated_POA::reference_to_id (
CORBA::Object_ptr reference,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->reference_to_id (
reference,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::Servant POA_PortableServer::_tao_collocated_POA::id_to_servant (
const PortableServer::ObjectId & oid,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->id_to_servant (
oid,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Object_ptr POA_PortableServer::_tao_collocated_POA::id_to_reference (
const PortableServer::ObjectId & oid,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->id_to_reference (
oid,
- _tao_environment
+ _tao_orb_environment
);
}
@@ -2794,9 +2836,10 @@ void POA_PortableServer::Current::get_POA_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_Current_get_POA_paramdata [] =
{
{PortableServer::_tc_POA, 0, 0}
@@ -2808,16 +2851,17 @@ void POA_PortableServer::Current::get_POA_skel (
POA_PortableServer::Current *_tao_impl = (POA_PortableServer::Current *)_tao_object_reference;
CORBA::Object_ptr _tao_retval = CORBA::Object::_nil ();
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_Current_get_POA_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->get_POA (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_Current_get_POA_calldata,
&_tao_retval
);
@@ -2827,9 +2871,10 @@ void POA_PortableServer::Current::get_object_id_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_Current_get_object_id_paramdata [] =
{
{PortableServer::_tc_ObjectId, 0, 0}
@@ -2841,16 +2886,17 @@ void POA_PortableServer::Current::get_object_id_skel (
POA_PortableServer::Current *_tao_impl = (POA_PortableServer::Current *)_tao_object_reference;
PortableServer::ObjectId *_tao_retval = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_Current_get_object_id_calldata,
_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->get_object_id (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_Current_get_object_id_calldata,
_tao_retval
);
@@ -2860,9 +2906,10 @@ void POA_PortableServer::Current::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel PortableServer_Current_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -2874,15 +2921,16 @@ void POA_PortableServer::Current::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&PortableServer_Current_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&PortableServer_Current_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -2892,13 +2940,13 @@ void POA_PortableServer::Current::_is_a_skel (
CORBA::Boolean POA_PortableServer::Current::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/Current:1.0")) ||
(!ACE_OS::strcmp ((char *)value, "IDL:PortableServer/CurrentBase:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -2954,30 +3002,30 @@ POA_PortableServer::Current_ptr POA_PortableServer::_tao_collocated_Current::_ge
CORBA::Boolean POA_PortableServer::_tao_collocated_Current::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::POA_ptr POA_PortableServer::_tao_collocated_Current::get_POA (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->get_POA (
- _tao_environment
+ _tao_orb_environment
);
}
PortableServer::ObjectId * POA_PortableServer::_tao_collocated_Current::get_object_id (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->get_object_id (
- _tao_environment
+ _tao_orb_environment
);
}
diff --git a/TAO/tao/PolicyS.cpp b/TAO/tao/PolicyS.cpp
index 19b57b38eba..5994b6f8ce4 100644
--- a/TAO/tao/PolicyS.cpp
+++ b/TAO/tao/PolicyS.cpp
@@ -40,9 +40,10 @@ void POA_CORBA::Policy::_get_policy_type_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel _get_CORBA_Policy_policy_type_paramdata [] =
{
{CORBA::_tc_PolicyType, 0, 0}
@@ -54,16 +55,17 @@ void POA_CORBA::Policy::_get_policy_type_skel (
POA_CORBA::Policy *_tao_impl = (POA_CORBA::Policy *)_tao_object_reference;
CORBA::PolicyType _tao_retval = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&_get_CORBA_Policy_policy_type_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->policy_type (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&_get_CORBA_Policy_policy_type_calldata,
&_tao_retval
);
@@ -73,9 +75,10 @@ void POA_CORBA::Policy::copy_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel CORBA_Policy_copy_paramdata [] =
{
{CORBA::_tc_Policy, 0, 0}
@@ -87,16 +90,17 @@ void POA_CORBA::Policy::copy_skel (
POA_CORBA::Policy *_tao_impl = (POA_CORBA::Policy *)_tao_object_reference;
CORBA::Object_ptr _tao_retval = CORBA::Object::_nil ();
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&CORBA_Policy_copy_calldata,
&_tao_retval
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_retval = _tao_impl->copy (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&CORBA_Policy_copy_calldata,
&_tao_retval
);
@@ -106,9 +110,10 @@ void POA_CORBA::Policy::destroy_skel (
CORBA::ServerRequest &_tao_server_request,
void *_tao_object_reference,
void * /* context */,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel CORBA_Policy_destroy_paramdata [] =
{
{CORBA::_tc_void, 0, 0}
@@ -119,16 +124,17 @@ void POA_CORBA::Policy::destroy_skel (
POA_CORBA::Policy *_tao_impl = (POA_CORBA::Policy *)_tao_object_reference;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&CORBA_Policy_destroy_calldata,
0
);
- if (_tao_environment.exception ()) return;
+ if (_tao_orb_environment.exception ()) return;
_tao_impl->destroy (
- _tao_environment
+ _tao_skel_environment
);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&CORBA_Policy_destroy_calldata,
0
);
@@ -138,9 +144,10 @@ void POA_CORBA::Policy::_is_a_skel (
CORBA::ServerRequest &_tao_server_request,
void * _tao_object_reference,
void * /*context*/,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
+ CORBA::Environment _tao_skel_environment;
static const TAO_Param_Data_Skel CORBA_Policy_is_a_paramdata [] =
{
{CORBA::_tc_boolean, 0, 0},
@@ -152,15 +159,16 @@ void POA_CORBA::Policy::_is_a_skel (
CORBA::Boolean _tao_retval;
char *_tao_value = 0;
_tao_server_request.demarshal (
- _tao_environment,
+ _tao_orb_environment,
&CORBA_Policy_is_a_calldata,
&_tao_retval,
&_tao_value
);
- if (_tao_environment.exception () != 0) return;
- _tao_retval = _tao_impl->_is_a (_tao_value, _tao_environment);
+ if (_tao_orb_environment.exception () != 0) return;
+ _tao_retval = _tao_impl->_is_a (_tao_value, _tao_skel_environment);
_tao_server_request.marshal (
- _tao_environment,
+ _tao_orb_environment,
+ _tao_skel_environment,
&CORBA_Policy_is_a_calldata,
&_tao_retval,
&_tao_value
@@ -170,12 +178,12 @@ void POA_CORBA::Policy::_is_a_skel (
CORBA::Boolean POA_CORBA::Policy::_is_a (
const char* value,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
if (
(!ACE_OS::strcmp ((char *)value, "IDL:CORBA/Policy:1.0")) ||
- (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_environment))))
+ (!ACE_OS::strcmp ((char *)value, CORBA::_tc_Object->id (_tao_orb_environment))))
return CORBA::B_TRUE;
else
return CORBA::B_FALSE;
@@ -228,39 +236,39 @@ POA_CORBA::Policy_ptr POA_CORBA::_tao_collocated_Policy::_get_servant (void) con
CORBA::Boolean POA_CORBA::_tao_collocated_Policy::_is_a (
const char* logical_type_id,
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->_is_a (
logical_type_id,
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::PolicyType POA_CORBA::_tao_collocated_Policy::policy_type (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->policy_type (
- _tao_environment
+ _tao_orb_environment
);
}
CORBA::Policy_ptr POA_CORBA::_tao_collocated_Policy::copy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
return this->servant_->copy (
- _tao_environment
+ _tao_orb_environment
);
}
void POA_CORBA::_tao_collocated_Policy::destroy (
- CORBA::Environment &_tao_environment
+ CORBA::Environment &_tao_orb_environment
)
{
this->servant_->destroy (
- _tao_environment
+ _tao_orb_environment
);
}
diff --git a/TAO/tao/Server_Request.h b/TAO/tao/Server_Request.h
index 9e46d3b5997..e47f2074848 100644
--- a/TAO/tao/Server_Request.h
+++ b/TAO/tao/Server_Request.h
@@ -150,12 +150,13 @@ public:
virtual CORBA::ORB_ptr orb (void) = 0;
// get the underlying ORB
- virtual void demarshal (CORBA::Environment &env,
+ virtual void demarshal (CORBA::Environment &orb_env,
const TAO_Call_Data_Skel *info,
...) = 0;
// demarshal incoming parameters
- virtual void marshal (CORBA::Environment &env,
+ virtual void marshal (CORBA::Environment &orb_env,
+ CORBA::Environment &skel_env,
const TAO_Call_Data_Skel *info,
...) = 0;
// marshal outgoing parameters
@@ -223,13 +224,14 @@ public:
// meant to be used internally.
//
- virtual void demarshal (CORBA::Environment &env,
+ virtual void demarshal (CORBA::Environment &orb_env,
const TAO_Call_Data_Skel *info,
...);
// demarshal incoming parameters. Used by the SSI skeleton (i.e., the IDL
// compiler generated skeleton)
- virtual void marshal (CORBA::Environment &env,
+ virtual void marshal (CORBA::Environment &orb_env,
+ CORBA::Environment &skel_env,
const TAO_Call_Data_Skel *info,
...);
// marshal outgoing parameters and return value. This is used by the SSI
diff --git a/TAO/tao/decode.cpp b/TAO/tao/decode.cpp
index 4e1fa962c5c..372cb7db193 100644
--- a/TAO/tao/decode.cpp
+++ b/TAO/tao/decode.cpp
@@ -763,10 +763,12 @@ TAO_Marshal_Struct::decode (CORBA::TypeCode_ptr tc,
break;
case CORBA::tk_string:
case CORBA::tk_wstring:
- case CORBA::tk_any:
case CORBA::tk_TypeCode:
- case CORBA::tk_Principal:
case CORBA::tk_objref:
+ retval = stream->decode (param, &data, 0, env);
+ break;
+ case CORBA::tk_any:
+ case CORBA::tk_Principal:
case CORBA::tk_struct:
case CORBA::tk_union:
case CORBA::tk_sequence:
diff --git a/TAO/tao/orbconf.h b/TAO/tao/orbconf.h
index 6f11bd03b26..3799499aa73 100644
--- a/TAO/tao/orbconf.h
+++ b/TAO/tao/orbconf.h
@@ -42,19 +42,19 @@
#define TAO_SOCK_CONNECTOR ACE_SOCK_CONNECTOR
#endif /* TAO_SOCK_CONNECTOR */
-// The default arguments of the resource factory for the fake service
+// The default arguments of the resource factory for the fake service
// configurator
#if !defined (TAO_DEFAULT_RESOURCE_FACTORY_ARGS)
#define TAO_DEFAULT_RESOURCE_FACTORY_ARGS { "-ORBresources", "tss" }
#endif /* TAO_DEFAULT_RESOURCE_FACTORY_ARGS */
-// The default arguments of the client strategy factory for the fake service
+// The default arguments of the client strategy factory for the fake service
// configurator
#if !defined (TAO_DEFAULT_CLIENT_STRATEGY_FACTORY_ARGS)
#define TAO_DEFAULT_CLIENT_STRATEGY_FACTORY_ARGS { 0 }
#endif /* TAO_DEFAULT_CLIENT_STRATEGY_FACTORY_ARGS */
-// The default arguments of the server strategy factory for the fake service
+// The default arguments of the server strategy factory for the fake service
// configurator
#if !defined (TAO_DEFAULT_SERVER_STRATEGY_FACTORY_ARGS)
#define TAO_DEFAULT_SERVER_STRATEGY_FACTORY_ARGS { "-ORBconcurrency", "reactive", \
@@ -113,6 +113,13 @@
# define TAO_MAXIMUM_NATIVE_TYPE_SIZE 128
#endif /* TAO_MAXIMUM_NATIVE_TYPE_SIZE */
+// This deals with platforms that support namespaces vs platforms that don't.
+#if defined (ACE_HAS_USING_KEYWORD)
+#define TAO_NAMESPACE namespace
+#else
+#define TAO_NAMESPACE struct
+#endif
+
//
// In some environments it is useful to swap the bytes on write, for
// instance: a fast server can be feeding a lot of slow clients that
diff --git a/TAO/tao/Server_Request.cpp b/TAO/tao/Server_Request.cpp
index 951bec9944e..bb0e0e53f78 100644
--- a/TAO/tao/Server_Request.cpp
+++ b/TAO/tao/Server_Request.cpp
@@ -237,10 +237,13 @@ IIOP_ServerRequest::set_exception (const CORBA::Any &value,
// Extension
void
-IIOP_ServerRequest::demarshal (CORBA::Environment &env, // exception reporting
- const TAO_Call_Data_Skel *info, // call description
- ...) // ... any parameters
+IIOP_ServerRequest::demarshal (CORBA::Environment &orb_env,
+ // ORB related exception reporting
+ const TAO_Call_Data_Skel *info,
+ // call description
+ ...)
{
+ // initialize a container object to hold the parameters
CORBA::NVList_ptr nvlist;
// Create an NVList
@@ -263,51 +266,55 @@ IIOP_ServerRequest::demarshal (CORBA::Environment &env, // exception reporting
if ((pdp->mode == CORBA::ARG_IN)
|| (pdp->mode == CORBA::ARG_INOUT))
// Populate the NVList.
- (void) nvlist->add_item (0, pdp->mode, env)->value ()->replace (pdp->tc, ptr, pdp->own, env);
+ (void) nvlist->add_item (0, pdp->mode, orb_env)->value ()
+ ->replace (pdp->tc, ptr, pdp->own, orb_env);
else if (pdp->mode == CORBA::ARG_OUT)
// Don't add any value.
- (void) nvlist->add_item (0, pdp->mode, env);
+ (void) nvlist->add_item (0, pdp->mode, orb_env);
}
va_end (param_vector);
// Now demarshal the parameters using a call to params.
- this->arguments (nvlist, env); // nvlist is now owned by us
+ this->arguments (nvlist, orb_env); // nvlist is now owned by us
}
// Extension
void
-IIOP_ServerRequest::marshal (CORBA::Environment &env, // exception reporting
- const TAO_Call_Data_Skel *info, // call description
- ...) // ... any parameters
+IIOP_ServerRequest::marshal (CORBA::Environment &orb_env,
+ // ORB related exception reporting
+ CORBA::Environment &skel_env,
+ // skeleton related exception reporting
+ const TAO_Call_Data_Skel *info,
+ // call description
+ ...)
{
// what is "env" and "env2"?
// "env" holds the exception that got raised during the dispatch process and
// inside the operation implementation (upcall)
//
- // "env2" is a local variable used here to identify any exceptions that get
- // raised doing the marshaling
- CORBA::Environment env2;
+ // "orb_env" is the exception that may have been raised due to things going
+ // wrong in the entire dispatch process. These are always system exceptions.
// check if we are inside with an exception. This may have happened
// since the upcall could have set some exception
- if (env.exception ())
+ if (skel_env.exception ())
{
// don't own it because ultimately it will be owned by the Server_Request
// via a call to "set_exception"
- CORBA::Any any (env.exception ()->_type (), env.exception ());
- this->set_exception (any, env2);
+ CORBA::Any any (skel_env.exception ()->_type (), skel_env.exception ());
+ this->set_exception (any, orb_env);
}
// Setup a Reply message so that we can marshal all the outgoing parameters
// into it. If an exception was set, then that gets marshaled into the reply
// message and we don't do anything after that
- this->init_reply (env2);
+ this->init_reply (orb_env);
// exception? nothing to do after this
- if (env2.exception () || env.exception ())
+ if (orb_env.exception () || skel_env.exception ())
return;
// Now, put all "in" and "inout" parameters into the NVList.
@@ -330,7 +337,7 @@ IIOP_ServerRequest::marshal (CORBA::Environment &env, // exception reporting
if (pdp->mode == 0)
{
// check if the return type is not void
- if (pdp->tc->kind (env2) != CORBA::tk_void)
+ if (pdp->tc->kind (orb_env) != CORBA::tk_void)
{
this->retval_ = new CORBA::Any (pdp->tc, ptr, pdp->own);
}
@@ -340,7 +347,7 @@ IIOP_ServerRequest::marshal (CORBA::Environment &env, // exception reporting
if (pdp->mode == CORBA::ARG_OUT)
// don't add any value. The skeletons generated by the TAO IDL compiler
// make sure that the Any does not own the data
- (void) this->params_->item (j, env)->value ()->replace (pdp->tc, ptr, pdp->own, env);
+ (void) this->params_->item (j, orb_env)->value ()->replace (pdp->tc, ptr, pdp->own, orb_env);
j++;
}
@@ -351,7 +358,7 @@ IIOP_ServerRequest::marshal (CORBA::Environment &env, // exception reporting
// these Anys don't own the data.
// Normal reply.
- if (!env.exception ())
+ if (!orb_env.exception ())
{
// ... then send any return value ...
if (this->retval_)
@@ -360,7 +367,7 @@ IIOP_ServerRequest::marshal (CORBA::Environment &env, // exception reporting
const void *value = this->retval_->value ();
if (value)
- (void) this->outgoing_->encode (tc, value, 0, env);
+ (void) this->outgoing_->encode (tc, value, 0, orb_env);
}
// ... Followed by "inout" and "out" parameters, left to right
@@ -368,7 +375,7 @@ IIOP_ServerRequest::marshal (CORBA::Environment &env, // exception reporting
i < this->params_->count ();
i++)
{
- CORBA::NamedValue_ptr nv = this->params_->item (i, env);
+ CORBA::NamedValue_ptr nv = this->params_->item (i, orb_env);
CORBA::Any_ptr any;
if (!(nv->flags () & (CORBA::ARG_INOUT|CORBA::ARG_OUT)))
@@ -377,7 +384,7 @@ IIOP_ServerRequest::marshal (CORBA::Environment &env, // exception reporting
any = nv->value ();
CORBA::TypeCode_ptr tc = any->type ();
const void *value = any->value ();
- (void) this->outgoing_->encode (tc, value, 0, env);
+ (void) this->outgoing_->encode (tc, value, 0, orb_env);
}
}
}
@@ -263,51 +266,55 @@ IIOP_ServerRequest::demarshal (CORBA::Environment &env, // exception reporting
{
- // what is "env" and "env2"?
- // "env" holds the exception that got raised during the dispatch process and
- // inside the operation implementation (upcall)
+ // what is "orb_env" and "skel_env"?
+ // "skel_env" holds the exception that got raised inside the operation
+ // implementation (upcall)
//